@@ -340,7 +340,7 @@ sub op_switch_map {
 
             my $own_subscription = $source->subscribe($own_subscriber);
 
-            return $own_subscription;
+            return [$own_subscription, \$current_subscription];
         });
     }
 }
